Changelog
=========


0.2.0 (2024-08-14)
------------------

- Send email only if given level is ERROR.
  [sgeulette]

0.1.0 (2024-08-14)
------------------

- Initial release with @message-receiver endpoint.
  [sgeulette]
